package com.hp.teach.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hp.teach.mapper.TeachInspectionItemsMapper;
import com.hp.teach.domain.TeachInspectionItems;
import com.hp.teach.service.ITeachInspectionItemsService;
import com.hp.common.support.Convert;

/**
 * 考核项（考核标准子） 服务层实现
 * 
 * @author hp
 * @date 2019-02-15
 */
@Service
public class TeachInspectionItemsServiceImpl implements ITeachInspectionItemsService 
{
	@Autowired
	private TeachInspectionItemsMapper teachInspectionItemsMapper;

	/**
     * 查询考核项（考核标准子）信息
     * 
     * @param inspectionItemsId 考核项（考核标准子）ID
     * @return 考核项（考核标准子）信息
     */
    @Override
	public TeachInspectionItems selectTeachInspectionItemsById(Integer inspectionItemsId)
	{
	    return teachInspectionItemsMapper.selectTeachInspectionItemsById(inspectionItemsId);
	}
	
	/**
     * 查询考核项（考核标准子）列表
     * 
     * @param teachInspectionItems 考核项（考核标准子）信息
     * @return 考核项（考核标准子）集合
     */
	@Override
	public List<TeachInspectionItems> selectTeachInspectionItemsList(TeachInspectionItems teachInspectionItems)
	{
	    return teachInspectionItemsMapper.selectTeachInspectionItemsList(teachInspectionItems);
	}
	
    /**
     * 新增考核项（考核标准子）
     * 
     * @param teachInspectionItems 考核项（考核标准子）信息
     * @return 结果
     */
	@Override
	public int insertTeachInspectionItems(TeachInspectionItems teachInspectionItems)
	{
	    return teachInspectionItemsMapper.insertTeachInspectionItems(teachInspectionItems);
	}
	
	/**
     * 修改考核项（考核标准子）
     * 
     * @param teachInspectionItems 考核项（考核标准子）信息
     * @return 结果
     */
	@Override
	public int updateTeachInspectionItems(TeachInspectionItems teachInspectionItems)
	{
	    return teachInspectionItemsMapper.updateTeachInspectionItems(teachInspectionItems);
	}

	/**
     * 删除考核项（考核标准子）对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
	@Override
	public int deleteTeachInspectionItemsByIds(String ids)
	{
		return teachInspectionItemsMapper.deleteTeachInspectionItemsByIds(Convert.toStrArray(ids));
	}
	
}
